@@ -2,23 +2,22 @@
  * 
  * hmm_main.h
  *
- * copyright (c) 2001-7, Karl W Broman
+ * copyright (c) 2001-9, Karl W Broman
  *
- * last modified Nov, 2007
+ * last modified Apr, 2009
  * first written Feb, 2001
  *
  *     This program is free software; you can redistribute it and/or
- *     modify it under the terms of the GNU General Public License, as
- *     published by the Free Software Foundation; either version 2 of
- *     the License, or (at your option) any later version. 
+ *     modify it under the terms of the GNU General Public License,
+ *     version 3, as published by the Free Software Foundation.
  * 
  *     This program is distributed in the hope that it will be useful,
  *     but without any warranty; without even the implied warranty of
- *     merchantability or fitness for a particular purpose.  See the
- *     GNU General Public License for more details.
+ *     merchantability or fitness for a particular purpose.  See the GNU
+ *     General Public License, version 3, for more details.
  * 
- *     A copy of the GNU General Public License is available at
- *     http://www.r-project.org/Licenses/
+ *     A copy of the GNU General Public License, version 3, is available
+ *     at http://www.r-project.org/Licenses/GPL-3
  *
  * C functions for the R/qtl package
  *
@@ -313,12 +312,14 @@ void calc_errorlod(int n_ind, int n_mar, int n_gen, int *geno,
  *
  * tol          Tolerance for determining convergence of the EM 
  *
+ * meioses_per  No. meioses per individual
+ *
  **********************************************************************/
 
 void est_rf(int n_ind, int n_mar, int *geno, double *rf, 
 	    double erec(int, int, double), 
 	    double logprec(int, int, double), 
-	    int maxit, double tol);
+	    int maxit, double tol, int meioses_per);
 
 /**********************************************************************
  * 
